==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Dependency.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a project dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.385Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Dependency")
@software.amazon.jsii.Jsii.Proxy(Dependency.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Dependency extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.DependencyCoordinates {

    /**
     * (experimental) Which type of dependency this is (runtime, build-time, etc).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DependencyType getType();

    /**
     * (experimental) Additional JSON metadata associated with the dependency (package manager specific).
     * <p>
     * Default: {}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Dependency> {
        io.github.cdklabs.projen.DependencyType type;
        java.util.Map<java.lang.String, java.lang.Object> metadata;
        java.lang.String name;
        java.lang.String version;

        /**
         * Sets the value of {@link Dependency#getType}
         * @param type Which type of dependency this is (runtime, build-time, etc). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(io.github.cdklabs.projen.DependencyType type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getMetadata}
         * @param metadata Additional JSON metadata associated with the dependency (package manager specific).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder metadata(java.util.Map<java.lang.String, ? extends java.lang.Object> metadata) {
            this.metadata = (java.util.Map<java.lang.String, java.lang.Object>)metadata;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getName}
         * @param name The package manager name of the dependency (e.g. `leftpad` for npm). This parameter is required.
         *             NOTE: For package managers that use complex coordinates (like Maven), we
         *             will codify it into a string somehow.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getVersion}
         * @param version Semantic version version requirement.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(java.lang.String version) {
            this.version = version;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Dependency}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Dependency build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Dependency {
        private final io.github.cdklabs.projen.DependencyType type;
        private final java.util.Map<java.lang.String, java.lang.Object> metadata;
        private final java.lang.String name;
        private final java.lang.String version;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DependencyType.class));
            this.metadata = software.amazon.jsii.Kernel.get(this, "metadata", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.version = software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.metadata = (java.util.Map<java.lang.String, java.lang.Object>)builder.metadata;
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.version = builder.version;
        }

        @Override
        public final io.github.cdklabs.projen.DependencyType getType() {
            return this.type;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return this.metadata;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getVersion() {
            return this.version;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("type", om.valueToTree(this.getType()));
            if (this.getMetadata() != null) {
                data.set("metadata", om.valueToTree(this.getMetadata()));
            }
            data.set("name", om.valueToTree(this.getName()));
            if (this.getVersion() != null) {
                data.set("version", om.valueToTree(this.getVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.Dependency"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Dependency.Jsii$Proxy that = (Dependency.Jsii$Proxy) o;

            if (!type.equals(that.type)) return false;
            if (this.metadata != null ? !this.metadata.equals(that.metadata) : that.metadata != null) return false;
            if (!name.equals(that.name)) return false;
            return this.version != null ? this.version.equals(that.version) : that.version == null;
        }

        @Override
        public final int hashCode() {
            int result = this.type.hashCode();
            result = 31 * result + (this.metadata != null ? this.metadata.hashCode() : 0);
            result = 31 * result + (this.name.hashCode());
            result = 31 * result + (this.version != null ? this.version.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Dependency.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a project dependency.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.074Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Dependency")
@software.amazon.jsii.Jsii.Proxy(Dependency.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Dependency extends software.amazon.jsii.JsiiSerializable, io.github.cdklabs.projen.DependencyCoordinates {

    /**
     * (experimental) Which type of dependency this is (runtime, build-time, etc).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DependencyType getType();

    /**
     * (experimental) Additional JSON metadata associated with the dependency (package manager specific).
     * <p>
     * Default: {}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Dependency> {
        io.github.cdklabs.projen.DependencyType type;
        java.util.Map<java.lang.String, java.lang.Object> metadata;
        java.lang.String name;
        java.lang.String version;

        /**
         * Sets the value of {@link Dependency#getType}
         * @param type Which type of dependency this is (runtime, build-time, etc). This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(io.github.cdklabs.projen.DependencyType type) {
            this.type = type;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getMetadata}
         * @param metadata Additional JSON metadata associated with the dependency (package manager specific).
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder metadata(java.util.Map<java.lang.String, ? extends java.lang.Object> metadata) {
            this.metadata = (java.util.Map<java.lang.String, java.lang.Object>)metadata;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getName}
         * @param name The package manager name of the dependency (e.g. <code>leftpad</code> for npm). This parameter is required.
         *             NOTE: For package managers that use complex coordinates (like Maven), we
         *             will codify it into a string somehow.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(java.lang.String name) {
            this.name = name;
            return this;
        }

        /**
         * Sets the value of {@link Dependency#getVersion}
         * @param version Semantic version version requirement.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(java.lang.String version) {
            this.version = version;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Dependency}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Dependency build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Dependency}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Dependency {
        private final io.github.cdklabs.projen.DependencyType type;
        private final java.util.Map<java.lang.String, java.lang.Object> metadata;
        private final java.lang.String name;
        private final java.lang.String version;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DependencyType.class));
            this.metadata = software.amazon.jsii.Kernel.get(this, "metadata", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.name = software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.version = software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
            this.metadata = (java.util.Map<java.lang.String, java.lang.Object>)builder.metadata;
            this.name = java.util.Objects.requireNonNull(builder.name, "name is required");
            this.version = builder.version;
        }

        @Override
        public final io.github.cdklabs.projen.DependencyType getType() {
            return this.type;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getMetadata() {
            return this.metadata;
        }

        @Override
        public final java.lang.String getName() {
            return this.name;
        }

        @Override
        public final java.lang.String getVersion() {
            return this.version;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("type", om.valueToTree(this.getType()));
            if (this.getMetadata() != null) {
                data.set("metadata", om.valueToTree(this.getMetadata()));
            }
            data.set("name", om.valueToTree(this.getName()));
            if (this.getVersion() != null) {
                data.set("version", om.valueToTree(this.getVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.Dependency"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Dependency.Jsii$Proxy that = (Dependency.Jsii$Proxy) o;

            if (!type.equals(that.type)) return false;
            if (this.metadata != null ? !this.metadata.equals(that.metadata) : that.metadata != null) return false;
            if (!name.equals(that.name)) return false;
            return this.version != null ? this.version.equals(that.version) : that.version == null;
        }

        @Override
        public final int hashCode() {
            int result = this.type.hashCode();
            result = 31 * result + (this.metadata != null ? this.metadata.hashCode() : 0);
            result = 31 * result + (this.name.hashCode());
            result = 31 * result + (this.version != null ? this.version.hashCode() : 0);
            return result;
        }
    }
}
